import { Construct } from '@aws-cdk/core';
import { ContainerDefinition } from '../container-definition';
import { AwsLogDriverProps } from './aws-log-driver';
/**
 * Base class for log drivers
 */
export declare abstract class LogDriver {
    /**
     * Create an AWS Logs logdriver
     */
    static awsLogs(props: AwsLogDriverProps): LogDriver;
    /**
     * Called when the log driver is configured on a container
     */
    abstract bind(scope: Construct, containerDefinition: ContainerDefinition): LogDriverConfig;
}
/**
 * Configuration to create a log driver from
 */
export interface LogDriverConfig {
    /**
     * Name of the log driver to use
     */
    readonly logDriver: string;
    /**
     * Log-driver specific option set
     */
    readonly options?: {
        [key: string]: string;
    };
}
